@@ -391,7 +391,7 @@ class File(PathObject):
     
     def copy(self, dest, overwrite=True, meta=True):
         if isinstance(dest, Folder):
-            dest = dest[self.basename,]
+            dest = dest + self.basename
         elif p.isdir(dest):
             dest = p.join(dest, self.basename)
         if (not overwrite) and p.exists(dest):
@@ -404,7 +404,7 @@ class File(PathObject):
     if hasattr(os, 'symlink'):
         def symlink(self, dest, overwrite=True):
             if isinstance(dest, Folder):
-                dest = dest[self.basename,]
+                dest = dest + self.basename
             elif p.isdir(dest):
                 dest = p.join(dest, self.basename)
             if (not overwrite) and p.exists(dest):
